@@ -255,7 +255,7 @@ void Sidebar_Widget::doLayout()
 {
     delete m_layout;
     m_layout = new QHBoxLayout(this);
-    m_layout->setMargin(0);
+    m_layout->setContentsMargins(0, 0, 0, 0);
     m_layout->setSpacing(0);
     if (m_showTabsLeft) {
         m_layout->addWidget(m_buttonBar);
@@ -830,7 +830,7 @@ void Sidebar_Widget::slotStatResult(KJob *job)
 {
     KIO::StatJob *statJob = static_cast<KIO::StatJob *>(job);
     if (statJob->error()) {
-        statJob->ui()->showErrorMessage();
+        statJob->uiDelegate()->showErrorMessage();
     } else {
         const QUrl url = statJob->url();
         KFileItem item(statJob->statResult(), url);
