@@ -44,7 +44,7 @@
 
 KonqHistoryView::KonqHistoryView(QWidget *parent)
     : QWidget(parent)
-    , m_searchTimer(0)
+    , m_searchTimer(nullptr)
 {
     m_treeView = new QTreeView(this);
     m_treeView->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -116,7 +116,7 @@ KonqHistoryView::KonqHistoryView(QWidget *parent)
     connect(m_searchLineEdit, &KLineEdit::textChanged, this, &KonqHistoryView::slotFilterTextChanged);
 
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->addWidget(m_searchLineEdit);
     mainLayout->addWidget(m_treeView);
 }
